@@ -23,6 +23,7 @@
 
 #include "action.h"
 #include "annotations.h"
+#include "document_p.h"
 #include "page.h"
 #include "textpage.h"
 
@@ -261,8 +262,7 @@ void TextDocumentGeneratorPrivate::initializeGenerator()
     q->setFeature( Generator::PrintNative );
     q->setFeature( Generator::PrintToFile );
 #ifdef OKULAR_TEXTDOCUMENT_THREADED_RENDERING
-    if ( QFontDatabase::supportsThreadedFontRendering() )
-        q->setFeature( Generator::Threaded );
+    q->setFeature( Generator::Threaded );
 #endif
 
     QObject::connect( mConverter, SIGNAL(addAction(Action*,int,int)),
@@ -563,5 +563,24 @@ TextDocumentSettings* TextDocumentGenerator::generalSettings()
     return d->mGeneralSettings;
 }
 
+TextDocumentConverter* TextDocumentGenerator::converter()
+{
+    Q_D( TextDocumentGenerator );
+
+    return d->mConverter;
+}
+
+void TextDocumentGenerator::setTextDocument( QTextDocument *textDocument )
+{
+    Q_D( TextDocumentGenerator );
+
+    d->mDocument = textDocument;
+
+    Q_FOREACH (Page *p, d->m_document->m_pagesVector )
+    {
+        p->setTextPage( nullptr );
+    }
+}
+
 #include "moc_textdocumentgenerator.cpp"
 
