@@ -311,9 +311,7 @@ PresentationWidget::~PresentationWidget()
     delete m_drawingEngine;
 
     // delete frames
-    QVector< PresentationFrame * >::iterator fIt = m_frames.begin(), fEnd = m_frames.end();
-    for ( ; fIt != fEnd; ++fIt )
-        delete *fIt;
+    qDeleteAll( m_frames );
 }
 
 
@@ -325,25 +323,20 @@ void PresentationWidget::notifySetup( const QVector< Okular::Page * > & pageSet,
         return;
 
     // delete previous frames (if any (shouldn't be))
-    QVector< PresentationFrame * >::iterator fIt = m_frames.begin(), fEnd = m_frames.end();
-    for ( ; fIt != fEnd; ++fIt )
-        delete *fIt;
+    qDeleteAll( m_frames );
     if ( !m_frames.isEmpty() )
         qCWarning(OkularUiDebug) << "Frames setup changed while a Presentation is in progress.";
     m_frames.clear();
 
     // create the new frames
-    QVector< Okular::Page * >::const_iterator setIt = pageSet.begin(), setEnd = pageSet.end();
     float screenRatio = (float)m_height / (float)m_width;
-    for ( ; setIt != setEnd; ++setIt )
+    for ( const Okular::Page * page : pageSet )
     {
         PresentationFrame * frame = new PresentationFrame();
-        frame->page = *setIt;
-        const QLinkedList< Okular::Annotation * > annotations = (*setIt)->annotations();
-        QLinkedList< Okular::Annotation * >::const_iterator aIt = annotations.begin(), aEnd = annotations.end();
-        for ( ; aIt != aEnd; ++aIt )
+        frame->page = page;
+        const QLinkedList< Okular::Annotation * > annotations = page->annotations();
+        for ( Okular::Annotation * a : annotations )
         {
-            Okular::Annotation * a = *aIt;
             if ( a->subType() == Okular::Annotation::AMovie )
             {
                 Okular::MovieAnnotation * movieAnn = static_cast< Okular::MovieAnnotation * >( a );
@@ -742,15 +735,13 @@ void PresentationWidget::mousePressEvent( QMouseEvent * e )
             }
         }
     }
-    // pressing the "move forward" mouse button: unlike the left button this
-    // always means "show next page", so we unconditionally delegate to that
-    // action on mouse button press
+    // pressing forward button
     else if ( e->button() == Qt::ForwardButton ) {
-        slotNextPage();
+        m_goToNextPageOnRelease = true;
     }
     // pressing right or backward button
     else if ( e->button() == Qt::RightButton || e->button() == Qt::BackButton )
-        slotPrevPage();
+        m_goToPreviousPageOnRelease = true;
 }
 
 void PresentationWidget::mouseReleaseEvent( QMouseEvent * e )
@@ -906,16 +897,21 @@ void PresentationWidget::paintEvent( QPaintEvent * pe )
 
         const QRect & geom = m_frames[ m_frameIndex ]->geometry;
 
-        QPixmap pm( geom.size() );
+        const QSize pmSize( geom.width() * dpr, geom.height() * dpr );
+        QPixmap pm( pmSize );
         pm.fill( Qt::transparent );
         QPainter pmPainter( &pm );
 
+        pm.setDevicePixelRatio( dpr );
         pmPainter.setRenderHints( QPainter::Antialiasing );
-        foreach ( const SmoothPath &drawing, m_frames[ m_frameIndex ]->drawings )
-            drawing.paint( &pmPainter, geom.width(), geom.height() );
 
+        // Paint old paths
+        foreach ( const SmoothPath &drawing, m_frames[ m_frameIndex ]->drawings )
+            drawing.paint( &pmPainter, pmSize.width(), pmSize.height() );
+
+        // Paint the path that is currently being drawn by the user
         if ( m_drawingEngine && m_drawingRect.intersects( pe->rect() ) )
-            m_drawingEngine->paint( &pmPainter, geom.width(), geom.height(), m_drawingRect.intersected( pe->rect() ) );
+            m_drawingEngine->paint( &pmPainter, pmSize.width(), pmSize.height(), m_drawingRect.intersected( pe->rect() ) );
 
         painter.setRenderHints( QPainter::Antialiasing );
         painter.drawPixmap( geom.topLeft() , pm );
@@ -1331,8 +1327,9 @@ QRect PresentationWidget::routeMouseDrawingEvent( QMouseEvent * e )
     if ( eventType == AnnotatorEngine::Press )
         hasclicked = true;
 
-    double nX = ( (double)e->x() - (double)geom.left() ) / (double)geom.width();
-    double nY = ( (double)e->y() - (double)geom.top() ) / (double)geom.height();
+    QPointF mousePos = e->localPos();
+    double nX = ( mousePos.x() - (double)geom.left() ) / (double)geom.width();
+    double nY = ( mousePos.y() - (double)geom.top() ) / (double)geom.height();
     QRect ret;
     bool isInside = nX >= 0 && nX < 1 && nY >= 0 && nY < 1;
 
@@ -1734,11 +1731,10 @@ void PresentationWidget::applyNewScreenSize( const QSize & oldSize )
     m_height = height();
 
     // update the frames
-    QVector< PresentationFrame * >::const_iterator fIt = m_frames.constBegin(), fEnd = m_frames.constEnd();
     const float screenRatio = (float)m_height / (float)m_width;
-    for ( ; fIt != fEnd; ++fIt )
+    for ( PresentationFrame * frame : qAsConst( m_frames ) )
     {
-        (*fIt)->recalcGeometry( m_width, m_height, screenRatio );
+        frame->recalcGeometry( m_width, m_height, screenRatio );
     }
 
     if ( m_frameIndex != -1 )
@@ -1764,8 +1760,8 @@ void PresentationWidget::inhibitPowerManagement()
     QString reason = i18nc( "Reason for inhibiting the screensaver activation, when the presentation mode is active", "Giving a presentation" );
 
     if (!m_screenInhibitCookie) {
-        QDBusMessage message = QDBusMessage::createMethodCall("org.freedesktop.ScreenSaver", "/ScreenSaver",
-                                                              "org.freedesktop.ScreenSaver", "Inhibit");
+        QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.ScreenSaver"), QStringLiteral("/ScreenSaver"),
+                                                              QStringLiteral("org.freedesktop.ScreenSaver"), QStringLiteral("Inhibit"));
         message << QCoreApplication::applicationName();
         message << reason;
 
@@ -1810,8 +1806,8 @@ void PresentationWidget::allowPowerManagement()
     }
 
     if (m_screenInhibitCookie) {
-        QDBusMessage message = QDBusMessage::createMethodCall("org.freedesktop.ScreenSaver", "/ScreenSaver",
-                                                              "org.freedesktop.ScreenSaver", "UnInhibit");
+        QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.ScreenSaver"), QStringLiteral("/ScreenSaver"),
+                                                              QStringLiteral("org.freedesktop.ScreenSaver"), QStringLiteral("UnInhibit"));
         message << m_screenInhibitCookie;
 
         QDBusPendingReply<uint> reply = QDBusConnection::sessionBus().asyncCall(message);
